<?php
/**
 * Functions and definitions
 *
 * @link https://slovenskoit.sk
 *
 * @package WordPress
 * @subpackage ID-SK
 * @since ID-SK 1.0
 */

if ( ! isset( $content_width ) ) {
	$content_width = 1920;
}

// Plugin activation
require get_template_directory() . '/classes/class-tgm-plugin-activation.php';
add_action( 'tgmpa_register', 'idsktmp_register_required_plugins' );

function idsktmp_register_required_plugins() {
	/*
	 * Array of plugin arrays.
	 */
	$plugins = array(
		array(
			'name'               => esc_html__( 'ID-SK Toolkit', 'idsk-template' ),
			'slug'               => 'idsk-toolkit',
			'required'           => false,
        ),
		array(
			'name'               => esc_html__( 'Contact Form 7', 'idsk-template' ),
			'slug'               => 'contact-form-7',
			'required'           => false,
        ),
	);

	/*
	 * Array of configuration settings. Amend each line as needed.
	 *
	 * TGMPA will start providing localized text strings soon. If you already have translations of our standard
	 * strings available, please help us make TGMPA even better by giving us access to these translations or by
	 * sending in a pull-request with .po file(s) with the translations.
	 *
	 * Only uncomment the strings in the config array if you want to customize the strings.
	 */
	$config = array(
		'id'           => 'idsktmp',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
	);

	tgmpa( $plugins, $config );
}

/**
 * Register and Enqueue Styles.
 */
function idsktmp_register_styles () {

    $theme_version = wp_get_theme()->get( 'Version' );

    wp_enqueue_style( 'idsktmp-style', get_stylesheet_uri(), array (), $theme_version );
    wp_enqueue_style( 'idsktmp-govuk-finder', get_template_directory_uri().'/assets/css/govuk-finder.css', null, $theme_version );
    wp_enqueue_style( 'idsktmp-search-form', get_template_directory_uri().'/assets/css/search-form.css', null, $theme_version );

    // Load webfonts
    wp_enqueue_style( 'idsktmp-fonts', get_stylesheet_directory_uri().'/assets/fonts/fonts.css', null, $theme_version );
}

add_action( 'wp_enqueue_scripts', 'idsktmp_register_styles' );

/**
 * Register and Enqueue Scripts.
 */
function idsktmp_register_scripts () {

    $theme_version = wp_get_theme()->get( 'Version' );

    wp_enqueue_script( 'idsktmp-js', get_template_directory_uri().'/assets/js/index.js', array (), $theme_version, TRUE );
    wp_enqueue_script( 'idsktmp-js-feedback', get_template_directory_uri().'/assets/js/feedback.js', array (), $theme_version, TRUE );
    wp_enqueue_script( 'idsktmp-js-searchform', get_template_directory_uri().'/assets/js/searchform.js', array (), $theme_version, TRUE );
    wp_enqueue_script( 'idsktmp-js-govuk-init', get_template_directory_uri().'/assets/js/govuk-init.js', array (), $theme_version, TRUE );
    
}

add_action( 'wp_enqueue_scripts', 'idsktmp_register_scripts' );

// Custom logo and theme support
function idsktmp_custom_logo_setup() {
    $defaults = array(
        'height'               => 120,
        'width'                => 90,
        'flex-height'          => true,
        'flex-width'           => true
    );
 
    // Translations
    load_theme_textdomain( 'idsk-template', get_template_directory() . '/languages' );
    
    add_theme_support( 'custom-logo', $defaults );
    add_theme_support( 'title-tag' );
    add_theme_support( 'automatic-feed-links' );
}
 
add_action( 'after_setup_theme', 'idsktmp_custom_logo_setup' );

// Handle Customizer settings.
require get_template_directory() . '/classes/class-idsk-customize.php';

function idsktmp_custom_new_menu() {
    register_nav_menus(
        array(
            'primary_menu' => __( 'Hlavné menu', 'idsk-template' ),
            'footer_menu' => __( 'Menu pätičky', 'idsk-template' )
        )
    );
}
add_action( 'init', 'idsktmp_custom_new_menu' );

function idsktmp_widgets_init() {
    /* Footer extended widgety */
    /* Footer extended widgety - Základné dáta */
    register_sidebar(
        array(
            'name'          => __( 'Pätička - Základné dáta', 'idsk-template' ),
            'id'            => 'sidebar-3',
            'description'   => __( 'Po pridaní widgetu "Text", vložte obsah zobrazujúci sa na ľavo od loga v pätičke.', 'idsk-template' ),
            'before_widget' => '',
            'after_widget'  => '',
            'before_title'  => '',
            'after_title'   => '',
        )
    );
    /* Footer extended widgety - Formulár - Našli ste na stránke chybu? */
    register_sidebar(
        array(
            'name'          => __( 'Pätička - Feedback formulár - Našli ste na stránke chybu?', 'idsk-template' ),
            'id'            => 'sidebar-4',
            'description'   => __( 'Po pridaní widgetu "Text", vložte odkaz na kontaktný formulár, ktorý ste si vytvorili pomocou pluginu contact form 7 (príklad: [contact-form-7 id="95" title="Pomôžte nám zlepšiť stránku"]) ', 'idsk-template' ),
            'before_widget' => '',
            'after_widget'  => '',
            'before_title'  => '',
            'after_title'   => '',
        )
    );
    /* Footer extended - Jednoduchá navigácia */
    register_sidebar(
        array(
            'name'          => __( 'Pätička - Jednoduchá navigácia', 'idsk-template' ),
            'id'            => 'sidebar-1',
            'description'   => __( 'Po pridaní widgetu "Text" vložte požadujúci obsah s jednoduchou navigáciou.', 'idsk-template' ),
            'before_widget' => '',
            'after_widget'  => '',
            'before_title'  => '',
            'after_title'   => '',
        )
    );
    /* Footer extended widgety - Rozšírená navigácia */
    register_sidebar(
        array(
            'name'          => __( 'Pätička - Rozšírená navigácia', 'idsk-template' ),
            'id'            => 'sidebar-2',
            'description'   => __( 'Po pridaní widgetu "Text" vložte požadujúci obsah v rozšírenej navigácií.', 'idsk-template' ),
            'before_widget' => '',
            'after_widget'  => '',
            'before_title'  => '',
            'after_title'   => '',
        )
    );
}
add_action( 'widgets_init', 'idsktmp_widgets_init' );

// Custom template functions tags for the theme.
require get_template_directory() . '/inc/partials/template-functions.php';
require get_template_directory() . '/inc/partials/template-tags.php';
