<?php
/**
 * Custom template tags for this theme
 * 
 * @link https://slovenskoit.sk
 *
 * @package WordPress
 * @subpackage ID-SK
 * @since ID-SK 1.0
 */


/**
 * Custom menu classes
 */
function idsktmp_add_classes_on_li($classes, $item, $args) {
    $classes[] = 'idsk-header__navigation-item';
    return $classes;
}
add_filter('nav_menu_css_class','idsktmp_add_classes_on_li',1,3);

function idsktmp_add_menuclass($ulclass) {
    return preg_replace('/<a /', '<a class="idsk-header__link"', $ulclass);
}
add_filter('wp_nav_menu','idsktmp_add_menuclass');

/**
 * Custom comment links
 */
function idsktmp_edit_comment_link( $output ) {
    $myclass = 'govuk-link';
    return preg_replace( '/comment-edit-link/', 'comment-edit-link ' . $myclass, $output, 1 );
}
add_filter( 'edit_comment_link', 'idsktmp_edit_comment_link' );

function idsktmp_reply_comment_link( $output ) {
    $myclass = 'govuk-button';
    return preg_replace( '/comment-reply-link/', 'comment-reply-link ' . $myclass, $output, 1 );
}
add_filter( 'comment_reply_link', 'idsktmp_reply_comment_link' );

/**
 * Custom comment form
 */
// Custom comment fields
function idsktmp_comment_form( $fields ) {
	// Get variables used in the field array
	$req      	= get_option( 'require_name_email' );
	$html_req 	= ( $req ? " required='required'" : '' );
	$html5    	= current_theme_supports( 'html5', 'comment-form' );
	$commenter	= wp_get_current_commenter();
    $consent    = empty( $commenter['comment_author_email'] ) ? '' : ' checked="checked"';

	// Modify the author field
	$fields['author'] = '<div class="govuk-form-group">' . 
                            '<label class="govuk-label" for="author">' . __( 'Meno', 'idsk-template' ) . ( $req ? ' <span class="required">*</span>' : '' ) . '</label> ' . 
                            '<input class="govuk-input" id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" maxlength="245"' . $html_req . ' />
                        </div>';

	// Modify the email field
	$fields['email'] = '<div class="govuk-form-group">
                            <label class="govuk-label" for="email">' . __( 'Email', 'idsk-template' ) . ( $req ? ' <span class="required">*</span>' : '' ) . '</label> ' . 
                            '<input class="govuk-input" id="email" name="email" ' . ( $html5 ? 'type="email"' : 'type="text"' ) . ' value="' . esc_attr( $commenter['comment_author_email'] ) . '" maxlength="100" aria-describedby="email-notes"' . $html_req . ' />
                        </div>';
                        
	// Modify the url field
	$fields['url'] = '<div class="govuk-form-group">
                            <label class="govuk-label" for="url">' . __( 'Adresa webu', 'idsk-template' ) . '</label> ' . 
                            '<input class="govuk-input" id="url" name="url" ' . ( $html5 ? 'type="url"' : 'type="text"' ) . ' value="' . esc_attr( $commenter['comment_author_url'] ) . '" maxlength="200"' . $html_req . ' />
                        </div>';

    // Modify the cookies field
    $fields['cookies'] = '<div class="govuk-form-group">
                            <div class="govuk-checkboxes">
                                <div class="govuk-checkboxes__item">
                                    <input class="govuk-checkboxes__input" id="wp-comment-cookies-consent" name="wp-comment-cookies-consent" type="checkbox" value="yes"' . $consent . ' />' .
                                    '<label class="govuk-label govuk-checkboxes__label" for="wp-comment-cookies-consent">' . __( 'Uložiť moje meno, e-mail a webovú stránku v tomto prehliadači pre moje budúce komentáre.', 'idsk-template' ) . '</label>
                                </div>
                            </div>
                        </div>';
    
    return $fields;
}
add_filter( 'comment_form_default_fields', 'idsktmp_comment_form' );

// Custom comment textarea 
function idsktmp_comment_form_defaults( $defaults ) {

    $defaults['title_reply_before'] = '<h2 id="reply-title" class="govuk-heading-m">';
    $defaults['title_reply_after']  = '</h2>';

	$defaults['comment_field']      = '<div class="govuk-form-group">
                                            <label class="govuk-label" for="comment">' . __( 'Komentár', 'idsk-template' ) . ' <span class="required">*</span></label> 
                                            <textarea class="govuk-textarea" id="comment" name="comment" rows="5" maxlength="65525" required="required"></textarea>
                                        </div>';
    
    return $defaults;
}
add_filter( 'comment_form_defaults', 'idsktmp_comment_form_defaults' );

// Reorder comment fields
function idsktmp_comment_form_fields( $fields ) {
    $comment_field = $fields['comment'];
    $author_field = $fields['author'];
    $email_field = $fields['email'];
    $url_field = $fields['url'];
    $cookies_field = $fields['cookies'];
    unset( $fields['comment'] );
    unset( $fields['author'] );
    unset( $fields['email'] );
    unset( $fields['url'] );
    unset( $fields['cookies'] );
    $fields['author'] = $author_field;
    $fields['email'] = $email_field;
    $fields['url'] = $url_field;
    $fields['comment'] = $comment_field;
    $fields['cookies'] = $cookies_field;
    
    return $fields;
}
add_filter( 'comment_form_fields', 'idsktmp_comment_form_fields' );

/**
 * Custom post category
 */
function idsktmp_breadcrumb_category($thelist){
    $categories = get_the_category();
  
    if ( !$categories || is_wp_error($categories) ) {
      return $thelist;
    }
  
    $output = '';
    foreach ( $categories as $category ) {
      $output .= '<li class="category-' . $category->slug . ' govuk-breadcrumbs__list-item"><a class="govuk-breadcrumbs__link" href="' . esc_url(get_category_link($category->term_id)) . '">' . $category->name . '</a></li>';
    }
  
    return $output;
}
add_filter( 'the_category', 'idsktmp_breadcrumb_category');

// Custom excerpt more
function idsktmp_excerpt_more( $more ) {
	return '...';
}
add_filter('excerpt_more', 'idsktmp_excerpt_more');