<?php 
/**
 * Custom template tags for this theme
 * 
 * @link https://slovenskoit.sk
 *
 * @package WordPress
 * @subpackage ID-SK
 * @since ID-SK 1.0
 */

if ( ! function_exists( 'idsktmp_comment' ) ) {
	/**
	 * Print custom comment view.
	 */
	function idsktmp_comment($comment, $args, $depth) {

		$linkClass = 'govuk-link';

		if ( 'div' === $args['style'] ) {
			$tag       = 'div';
			$add_below = 'comment';
		} else {
			$tag       = 'div';
			$add_below = 'div-comment';
		}
		echo '<'.esc_attr($tag).' '.comment_class( empty( $args['has_children'] ) ? 'govuk-body' : 'govuk-body parent', '', '', false ).' id="comment-'.esc_attr( get_comment_id() ).'">';
		if ( 'div' != $args['style'] ) { 
			echo '<div id="div-comment-'.esc_attr( get_comment_id() ).'" class="comment-body">';
		}
			echo '<div class="comment-author vcard">';
				/* translators: %s: comment author */
				printf( esc_html__( '%s píše:', 'idsk-template' ), '<strong>'.esc_html( get_comment_author() ).'</strong>' );
			echo '</div>';
			
			if ( $comment->comment_approved == '0' ) { 
				echo '<em class="comment-awaiting-moderation">'.esc_html__( 'Váš komentár čaká na schválenie.', 'idsk-template' ).'</em><br/>';
			}
			echo '<div class="comment-meta commentmetadata">';
				echo '<a href="'.esc_url( get_comment_link( $comment->comment_ID ) ).'" class="govuk-link">';
					printf( 
						/* translators: 1: date, 2: time */
						esc_html__('%1$s o %2$s', 'idsk-template'), 
						esc_html(get_comment_date()),  
						esc_html(get_comment_time()) 
					); 
				echo '</a>';
				edit_comment_link( esc_html__( '(Upraviť)', 'idsk-template' ), '  ', '' );
			echo '</div>';
	
			comment_text();
	
			echo '<div class="reply">';
					comment_reply_link( 
						array_merge( 
							$args, 
							array( 
								'add_below' => $add_below, 
								'depth'     => $depth, 
								'max_depth' => $args['max_depth'] 
							) 
						) 
					);
			echo '</div>';
		if ( 'div' != $args['style'] ) { 
			echo '</div>';
		}
		echo '<hr class="govuk-section-break govuk-section-break--m govuk-section-break--visible" style="clear: both;">';
	}
}

if ( ! function_exists( 'idsktmp_get_breadcrumb' ) ) {
	/**
	 * Print custom breadcrumbs
	 */
	function idsktmp_get_breadcrumb() {
		global $post;

		echo '<div class="govuk-breadcrumbs">';
		echo '<ol class="govuk-breadcrumbs__list">';
		echo '<li class="govuk-breadcrumbs__list-item"><a class="govuk-breadcrumbs__link" href="'.esc_url( home_url() ).'">'. esc_html__( 'Domov', 'idsk-template' ) .'</a></li>';
		
		if (is_search()) {
			echo '<li class="govuk-breadcrumbs__list-item" aria-current="page">';
			echo esc_html__( 'Výsledky pre ', 'idsk-template' );
			echo '"<em>';
			echo esc_html(the_search_query());
			echo '</em>"';
			echo '</li>';
		} elseif (is_category() || is_single()) {
			the_category();
			if (is_single()) {
				the_title('<li class="govuk-breadcrumbs__list-item" aria-current="page">', '</li>');
			}
		} elseif (is_page()) {
			if ($post->post_parent) {
				$parents = get_post_ancestors($post->post_parent); // get all parents of parent
				// display all parents
				if (!empty($parents)) {
					foreach ($parents as $parent) {
						echo '<li class="govuk-breadcrumbs__list-item"><a class="govuk-breadcrumbs__link" href="'.esc_url(get_permalink($parent)).'">'.esc_html(get_the_title($parent)).'</a></li>';
					}
				}
				echo '<li class="govuk-breadcrumbs__list-item"><a class="govuk-breadcrumbs__link" href="'.esc_url(get_permalink($post->post_parent)).'">'.esc_html(get_the_title($post->post_parent)).'</a></li>';
			}
			the_title('<li class="govuk-breadcrumbs__list-item" aria-current="page">', '</li>');
		}
		echo '</ol>';
		echo '</div>';
	}
}

if ( ! function_exists( 'wp_body_open' ) ) {
	/**
	 * Fire the wp_body_open action.
	 *
	 * Added for backward compatibility to support pre-5.2.0 WordPress versions.
	 */
	function wp_body_open() {
		/**
		 * Triggered after the opening <body> tag.
		 */
		do_action( 'wp_body_open' );
	}
}
